/***************************************************************************
 *  include/stxxl/bits/containers/btree/root_node.h
 *
 *  Part of the STXXL. See http://stxxl.sourceforge.net
 *
 *  Copyright (C) 2006 Roman Dementiev <dementiev@ira.uka.de>
 *
 *  Distributed under the Boost Software License, Version 1.0.
 *  (See accompanying file LICENSE_1_0.txt or copy at
 *  http://www.boost.org/LICENSE_1_0.txt)
 **************************************************************************/

#ifndef STXXL_CONTAINERS_BTREE_ROOT_NODE_HEADER
#define STXXL_CONTAINERS_BTREE_ROOT_NODE_HEADER

#include <stxxl/bits/namespace.h>


STXXL_BEGIN_NAMESPACE

namespace btree {

template <class KeyType, class BIDType>
class root_node
{
    // a place for a future custom root node tree implementation
};

} // namespace btree

STXXL_END_NAMESPACE

#endif // !STXXL_CONTAINERS_BTREE_ROOT_NODE_HEADER
